@@ -6,7 +6,7 @@ use base qw( Data::Phrasebook::Debug );
 use Carp qw( croak );
 
 use vars qw($VERSION);
-$VERSION = '0.30';
+$VERSION = '0.32';
 
 =head1 NAME
 
@@ -291,11 +291,20 @@ The example below shows a Template Toolkit style regex.
 
    $q->delimiters( qr{ \[% \s* (\w+) \s* %\] }x );
 
+In addition to the delimiter pattern, an optional setting to suppress missing
+value errors can be passed after the pattern. If set to a true value, will 
+turn any unmatched delimiter patterns to an empty string.
+
 =cut
 
 sub delimiters {
     my $self = shift;
-    return @_ ? $self->{delimiters} = shift : $self->{delimiters};
+    if(@_) {
+        $self->{delimiters} = shift;
+        $self->{blank_args} = shift || 0;
+    }
+        
+    return $self->{delimiters};
 }
 
 1;
@@ -320,9 +329,9 @@ Please see the README file.
 =head1 COPYRIGHT AND LICENSE
 
   Copyright (C) 2003 Iain Truskett.
-  Copyright (C) 2004-2010 Barbie for Miss Barbell Productions.
+  Copyright (C) 2004-2012 Barbie for Miss Barbell Productions.
 
   This module is free software; you can redistribute it and/or
-  modify it under the Artistic Licence v2.
+  modify it under the Artistic License v2.
 
 =cut
